@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,20 +18,28 @@ package org.drools.workbench.screens.guided.dtable.client.editor;
 
 import java.lang.annotation.Annotation;
 import java.lang.reflect.Field;
+import java.util.Optional;
 import java.util.concurrent.atomic.AtomicInteger;
 
 import com.google.gwtmockito.GwtMockitoTestRunner;
+import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
 import org.drools.workbench.screens.guided.dtable.client.editor.clipboard.Clipboard;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.EditMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.InsertMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.RadarMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.RadarMenuView;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.ViewMenuBuilder;
+import org.drools.workbench.screens.guided.dtable.client.editor.page.ColumnsPage;
 import org.drools.workbench.screens.guided.dtable.client.type.GuidedDTableResourceType;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTableModellerView;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableSelectedEvent;
+import org.drools.workbench.screens.guided.dtable.client.wizard.column.NewGuidedDecisionTableColumnWizard;
+import org.drools.workbench.screens.guided.dtable.client.wizard.column.pages.common.DecisionTablePopoverUtils;
 import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService;
-import org.guvnor.common.services.project.context.ProjectContext;
+import org.guvnor.common.services.project.categories.Decision;
+import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
+import org.guvnor.common.services.shared.metadata.model.Metadata;
+import org.guvnor.messageconsole.client.console.widget.button.AlertsButtonMenuItemBuilder;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.dom.HTMLElement;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
@@ -60,7 +68,9 @@ import org.uberfire.ext.editor.commons.client.file.popups.SavePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.history.VersionRecordManager;
 import org.uberfire.ext.editor.commons.client.menu.BasicFileMenuBuilder;
 import org.uberfire.ext.editor.commons.client.menu.BasicFileMenuBuilderImpl;
+import org.uberfire.ext.editor.commons.client.menu.DownloadMenuItem;
 import org.uberfire.ext.editor.commons.client.menu.RestoreVersionCommandProvider;
+import org.uberfire.ext.editor.commons.client.menu.common.SaveAndRenameCommandBuilder;
 import org.uberfire.ext.editor.commons.client.validation.DefaultFileNameValidator;
 import org.uberfire.ext.editor.commons.version.VersionService;
 import org.uberfire.ext.editor.commons.version.events.RestoreEvent;
@@ -86,8 +96,12 @@ import org.uberfire.workbench.model.menu.MenuItemPlain;
 import org.uberfire.workbench.model.menu.MenuVisitor;
 import org.uberfire.workbench.model.menu.Menus;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.fail;
+import static org.mockito.Matchers.any;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
 public class GuidedDecisionTableEditorMenusTest {
@@ -126,6 +140,9 @@ public class GuidedDecisionTableEditorMenusTest {
     @Mock
     private ManagedInstance<MenuItemView> menuItemViewDividerProducer;
 
+    @Mock
+    private ManagedInstance<NewGuidedDecisionTableColumnWizard> wizardManagedInstance;
+
     private MenuItemFactory menuItemFactory;
 
     protected EditMenuBuilder editMenuBuilder;
@@ -177,7 +194,7 @@ public class GuidedDecisionTableEditorMenusTest {
     protected EventSourceMock<ChangeTitleWidgetEvent> changeTitleEvent;
 
     @Mock
-    protected ProjectContext workbenchContext;
+    protected WorkspaceProjectContext workbenchContext;
 
     @Mock
     protected VersionRecordManager versionRecordManager;
@@ -219,11 +236,32 @@ public class GuidedDecisionTableEditorMenusTest {
     @Mock
     protected PlaceManager placeManager;
 
+    @Mock
+    protected ColumnsPage columnsPage;
+
+    @Mock
+    protected SaveAndRenameCommandBuilder<GuidedDecisionTable52, Metadata> saveAndRenameCommandBuilder;
+
     @Mock
     protected MenuItemWithIconView menuItemWithIconView;
 
+    @Mock
+    private DecisionTablePopoverUtils popoverUtils;
+
+    @Mock
+    protected AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder;
+
+    @Mock
+    protected DownloadMenuItem downloadMenuItem;
+
+    @Mock
+    protected MenuItem downloadMenuItemButton;
+
+    @Mock
+    protected MenuItem alertsButtonMenuItem;
+
     private GuidedDecisionTableEditorPresenter presenter;
-    private GuidedDTableResourceType resourceType = new GuidedDTableResourceType();
+    private GuidedDTableResourceType resourceType = new GuidedDTableResourceType(new Decision());
 
     private String[] menuItemIdentifiers = new String[]{
             "org.uberfire.workbench.model.menu.impl.MenuBuilderImpl$CurrentContext$1#Delete",
@@ -256,6 +294,8 @@ public class GuidedDecisionTableEditorMenusTest {
 
     @Before
     public void setup() {
+        when(downloadMenuItem.build(any())).thenReturn(downloadMenuItemButton);
+        when(alertsButtonMenuItemBuilder.build()).thenReturn(alertsButtonMenuItem);
         when(modeller.getView()).thenReturn(modellerView);
         when(versionRecordManager.newSaveMenuItem(any(Command.class))).thenReturn(saveMenuItem);
         when(versionRecordManager.buildMenu()).thenReturn(versionManagerMenuItem);
@@ -282,10 +322,10 @@ public class GuidedDecisionTableEditorMenusTest {
 
         this.editMenuBuilder = new EditMenuBuilder(clipboard,
                                                    ts,
-                                                   menuItemFactory);
+                                                   menuItemFactory,
+                                                   popoverUtils);
         this.editMenuBuilder.setup();
-        this.insertMenuBuilder = new InsertMenuBuilder(ts,
-                                                       menuItemFactory);
+        this.insertMenuBuilder = new InsertMenuBuilder(ts, menuItemFactory, wizardManagedInstance);
         this.insertMenuBuilder.setup();
         this.insertMenuBuilder.setModeller(modeller);
         this.viewMenuBuilder = new ViewMenuBuilder(ts,
@@ -308,7 +348,16 @@ public class GuidedDecisionTableEditorMenusTest {
                                                                                                   radarMenuBuilder,
                                                                                                   modeller,
                                                                                                   beanManager,
-                                                                                                  placeManager);
+                                                                                                  placeManager,
+                                                                                                  columnsPage,
+                                                                                                  saveAndRenameCommandBuilder,
+                                                                                                  alertsButtonMenuItemBuilder,
+                                                                                                  downloadMenuItem) {
+            @Override
+            protected Command getSaveAndRenameCommand() {
+                return mock(Command.class);
+            }
+        };
 
         wrapped.setKieEditorWrapperView(kieEditorWrapperView);
         wrapped.setOverviewWidget(overviewWidget);
@@ -324,6 +373,9 @@ public class GuidedDecisionTableEditorMenusTest {
 
         this.presenter = spy(wrapped);
 
+        when(workbenchContext.getActiveOrganizationalUnit()).thenReturn(Optional.empty());
+        when(workbenchContext.getActiveWorkspaceProject()).thenReturn(Optional.empty());
+
         presenter.init();
         presenter.setupMenuBar();
     }
