@@ -15,18 +15,31 @@
  */
 package org.drools.workbench.screens.scenariosimulation.backend.server;
 
-import javax.enterprise.event.Event;
+import java.util.Collections;
+import java.util.HashSet;
+import java.util.Set;
 
+import javax.inject.Named;
+
+import org.assertj.core.api.Assertions;
+import org.drools.workbench.screens.scenariosimulation.backend.server.runner.ScenarioJunitActivator;
 import org.drools.workbench.screens.scenariosimulation.model.ScenarioSimulationModel;
-import org.drools.workbench.screens.scenariosimulation.model.ScenarioSimulationModelContent;
 import org.guvnor.common.services.backend.config.SafeSessionInfo;
 import org.guvnor.common.services.backend.metadata.MetadataServerSideService;
 import org.guvnor.common.services.backend.util.CommentedOptionFactory;
+import org.guvnor.common.services.project.model.Dependencies;
+import org.guvnor.common.services.project.model.GAV;
+import org.guvnor.common.services.project.model.POM;
+import org.guvnor.common.services.project.model.Package;
+import org.guvnor.common.services.project.service.POMService;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
-import org.guvnor.common.services.shared.metadata.model.Overview;
+import org.jboss.errai.security.shared.api.identity.User;
+import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.services.backend.service.KieServiceOverviewLoader;
+import org.kie.workbench.common.services.shared.project.KieModule;
+import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
@@ -40,20 +53,25 @@ import org.uberfire.ext.editor.commons.service.RenameService;
 import org.uberfire.io.IOService;
 import org.uberfire.java.nio.base.options.CommentedOption;
 import org.uberfire.java.nio.file.FileAlreadyExistsException;
-import org.uberfire.workbench.events.ResourceOpenedEvent;
+import org.uberfire.java.nio.file.OpenOption;
 
 import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyMap;
 import static org.mockito.Matchers.anyString;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.reset;
+import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class ScenarioSimulationServiceImplTest {
 
     @Mock
+    @Named("ioStrategy")
     private IOService ioService;
 
     @Mock
@@ -68,9 +86,6 @@ public class ScenarioSimulationServiceImplTest {
     @Mock
     protected KieServiceOverviewLoader overviewLoader;
 
-    @Mock
-    private Event<ResourceOpenedEvent> resourceOpenedEvent;
-
     @Mock
     protected MetadataServerSideService metadataService;
 
@@ -83,11 +98,58 @@ public class ScenarioSimulationServiceImplTest {
     @Mock
     private CopyService copyService;
 
+    @Mock
+    private User user;
+
+    @Mock
+    private ScenarioRunnerServiceImpl scenarioRunnerService;
+
+    @Mock
+    private POMService pomService;
+
+    @Mock
+    private org.uberfire.java.nio.file.Path activatorPath;
+
+    @Mock
+    private KieModuleService kieModuleService;
+
+    @Mock
+    private KieModule module;
+
+    @Mock
+    private POM projectPom;
+
+    @Mock
+    private GAV gav;
+
+    @Mock
+    private Dependencies dependencies;
+
+    @Mock
+    private Package mockedPackage;
+
     @InjectMocks
     private ScenarioSimulationServiceImpl service = new ScenarioSimulationServiceImpl(mock(SafeSessionInfo.class));
 
     private Path path = PathFactory.newPath("contextpath", "file:///contextpath");
 
+    @Before
+    public void setup() {
+        Set<Package> packages = new HashSet<>();
+        packages.add(new Package(path, path, path, path, path, "Test", "", ""));
+        when(kieModuleService.resolveModule(any())).thenReturn(module);
+        when(kieModuleService.resolvePackages(any(KieModule.class))).thenReturn(packages);
+        when(ioService.exists(activatorPath)).thenReturn(false);
+
+        when(kieModuleService.resolveModule(any())).thenReturn(module);
+        when(module.getPom()).thenReturn(projectPom);
+        when(projectPom.getGav()).thenReturn(gav);
+        when(gav.getGroupId()).thenReturn("Test");
+        when(projectPom.getDependencies()).thenReturn(dependencies);
+        when(ioService.exists(any(org.uberfire.java.nio.file.Path.class))).thenReturn(false);
+        when(mockedPackage.getPackageTestSrcPath()).thenReturn(path);
+    }
+
     @Test
     public void init() throws Exception {
         service.init();
@@ -152,17 +214,6 @@ public class ScenarioSimulationServiceImplTest {
                                                    "comment");
     }
 
-    @Test
-    public void loadContent() throws Exception {
-        doReturn("").when(ioService).readAllString(any());
-        doReturn(false).when(pathResolver).isDotFile(any());
-        doReturn(mock(Overview.class)).when(overviewLoader).loadOverview(any());
-        final ScenarioSimulationModelContent scenarioSimulationModelContent = service.loadContent(path);
-
-        assertNotNull(scenarioSimulationModelContent);
-        verify(resourceOpenedEvent).fire(any(ResourceOpenedEvent.class));
-    }
-
     @Test
     public void save() throws Exception {
 
@@ -188,9 +239,10 @@ public class ScenarioSimulationServiceImplTest {
                                                "Commit comment");
 
         assertNotNull(returnPath);
-        verify(ioService).write(any(org.uberfire.java.nio.file.Path.class),
-                                anyString(),
-                                any(CommentedOption.class));
+
+        verify(ioService, times(2)).write(any(org.uberfire.java.nio.file.Path.class),
+                                          anyString(),
+                                          any(CommentedOption.class));
     }
 
     @Test(expected = FileAlreadyExistsException.class)
@@ -202,4 +254,76 @@ public class ScenarioSimulationServiceImplTest {
                        new ScenarioSimulationModel(),
                        "Commit comment");
     }
+
+    @Test
+    public void runScenario() throws Exception {
+        doReturn("test user").when(user).getIdentifier();
+
+        final Path path = mock(Path.class);
+        final ScenarioSimulationModel model = new ScenarioSimulationModel();
+
+        service.runScenario(path, model);
+
+        verify(scenarioRunnerService).runTest("test user",
+                                              path,
+                                              model);
+    }
+
+    @Test
+    public void createActivatorIfNotExistTest() {
+        service.createActivatorIfNotExist(path);
+
+        verify(ioService, times(1))
+                .write(any(org.uberfire.java.nio.file.Path.class),
+                       anyString(),
+                       any(OpenOption.class));
+
+        when(kieModuleService.resolvePackages(any(KieModule.class))).thenReturn(Collections.emptySet());
+        Assertions.assertThatThrownBy(() -> service.createActivatorIfNotExist(path))
+                .isInstanceOf(IllegalArgumentException.class)
+                .hasMessage("Impossible to retrieve package information from path: file:///contextpath");
+    }
+
+    @Test
+    public void ensureDependenciesTest() {
+        service.ensureDependencies(module);
+
+        int expectedCalls = service.getDependecies(null).size();
+        verify(pomService, times(expectedCalls)).save(any(Path.class),
+                                                      any(POM.class),
+                                                      any(Metadata.class),
+                                                      anyString());
+    }
+
+    @Test
+    public void editPomIfNecessaryTest() {
+        String groupId = "groupId";
+        String artifactId = "artifactId";
+        String version = "version";
+        POM pom = new POM();
+        GAV gav = new GAV(groupId, artifactId, version);
+        Dependencies dependencies = new Dependencies();
+
+        service.editPomIfNecessary(path, pom, dependencies, gav);
+
+        verify(pomService, times(1))
+                .save(any(Path.class),
+                      any(POM.class),
+                      any(Metadata.class),
+                      anyString());
+
+        reset(pomService);
+        ;
+        service.editPomIfNecessary(path, pom, dependencies, gav);
+        verify(pomService, times(0))
+                .save(any(Path.class),
+                      any(POM.class),
+                      any(Metadata.class),
+                      anyString());
+    }
+
+    @Test
+    public void getActivatorPathTest() {
+        assertTrue(service.getActivatorPath(mockedPackage).endsWith(ScenarioJunitActivator.ACTIVATOR_CLASS_NAME + ".java"));
+    }
 }
\ No newline at end of file
